==> deepin-movie-reborn_5.0.0.orig.tar.gz: deepin-movie-reborn-5.0.0/src/widgets/slider.h <==
/* 
 * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
#ifndef _DMR_SLIDER_H
#define _DMR_SLIDER_H 

#include <QtWidgets>
namespace dmr {
class DMRSlider: public QSlider {
    Q_OBJECT
public:
    DMRSlider(QWidget *parent = 0);
    virtual ~DMRSlider();
    void setEnableIndication(bool on);

    //workaround
    void forceLeave();

signals:
    void hoverChanged(int);
    void leave();
    void enter();

protected:
    void onValueChanged(const QVariant& v);
    void onAnimationStopped();

protected:
    void mouseReleaseEvent(QMouseEvent *e) override;
    void mousePressEvent(QMouseEvent *e) override;
    void mouseMoveEvent(QMouseEvent *e) override;
    void leaveEvent(QEvent *e) override;
    void enterEvent(QEvent *e) override;
    void wheelEvent(QWheelEvent *e) override;
    void paintEvent(QPaintEvent *e) override;

private:
    bool _down {false};
    bool _indicatorEnabled {false};
    bool _showIndicator {false};
    int _lastHoverValue {0};
    QPoint _indicatorPos {0, 0};
    QColor _indicatorColor;

    QPointer<QVariantAnimation> _hoverAni {nullptr};
    const char* _style_tmpl {nullptr};

    int position2progress(const QPoint& p);
    void startAnimation(bool reverse);
};

}

#endif /* ifndef _DMR_SLIDER_H */

==> deepin-movie-reborn_5.7.6.147.orig.tar.gz: deepin-movie-reborn-5.7.6.147/src/widgets/slider.h <==
/* 
 * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
#ifndef _DMR_SLIDER_H
#define _DMR_SLIDER_H 

#include <QtWidgets>
#include <DSlider>
#include <DImageButton>
DWIDGET_USE_NAMESPACE
namespace dmr {
class DMRSlider: public DSlider {
    Q_OBJECT
public:
    DMRSlider(QWidget *parent = 0);
    virtual ~DMRSlider();
    void setEnableIndication(bool on);

    //workaround
    void forceLeave();

signals:
    void hoverChanged(int);
    void leave();
    void enter();

protected:
    void onValueChanged(const QVariant& v);
    void onAnimationStopped();

protected:
    void mouseReleaseEvent(QMouseEvent *e) override;
    void mousePressEvent(QMouseEvent *e) override;
    void mouseMoveEvent(QMouseEvent *e) override;
    void leaveEvent(QEvent *e) override;
    void enterEvent(QEvent *e) override;
    void wheelEvent(QWheelEvent *e) override;
    void paintEvent(QPaintEvent *e) override;

private:
    bool _down {false};
    bool _indicatorEnabled {false};
    bool _showIndicator {false};
    int _lastHoverValue {0};
    QPoint _indicatorPos {0, 0};
    QColor _indicatorColor;

    QPointer<QVariantAnimation> _hoverAni {nullptr};
    const char* _style_tmpl {nullptr};

    int position2progress(const QPoint& p);
    void startAnimation(bool reverse);
};

}

#endif /* ifndef _DMR_SLIDER_H */
